import { __awaiter, __decorate } from "tslib";
import { NotificationListener } from '@genesislcap/foundation-ui';
import { logger } from '@genesislcap/foundation-utils';
import { attr, customElement, html, ref } from '@genesislcap/web-core';
import { register, addEventListener, create, IndicatorColor, } from '@openfin/workspace/notifications';
const OpenfinGenesisPriorityMap = {
    Information: 1,
    Warning: 2,
    Serious: 3,
    Critical: 4,
};
const OpenfinGenesisColorMap = {
    Information: IndicatorColor.BLUE,
    Warning: IndicatorColor.YELLOW,
    Serious: IndicatorColor.MAGENTA,
    Critical: IndicatorColor.RED,
};
function initializeNotifications(notificationsPlatformOptions) {
    return __awaiter(this, void 0, void 0, function* () {
        yield register({
            notificationsPlatformOptions,
        });
    });
}
/**
 * @public
 * @remarks
 * Openfin Notifications custom element
 */
let OpenfinNotificationListener = class OpenfinNotificationListener extends NotificationListener {
    constructor() {
        super(...arguments);
        /**
         *  @beta
         *  @remarks
         *  The notification type of toast messages
         */
        this.toast = 'transient';
        /**
         *  @beta
         *  @remarks
         *  The notification sound mode
         */
        this.mode = 'silent';
    }
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.connectedCallback.call(this);
            yield initializeNotifications(this.notificationsPlatform);
            yield this.addButtonListeners();
        });
    }
    addButtonListeners() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield addEventListener('notification-action', (event) => {
                    var _a;
                    const button = (_a = this.toastButtons) === null || _a === void 0 ? void 0 : _a.find((t) => t.task === event.result.task);
                    if (!button) {
                        return;
                    }
                    button.action({ details: event.result.customData.details, buttonElement: this });
                });
            }
            catch (e) {
                console.log(e);
            }
        });
    }
    showNotificationToast(row) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const { HEADER: title, MESSAGE: body, NOTIFY_SEVERITY: type, ALERT_ID } = row;
            const notification = {
                title,
                body,
                priority: OpenfinGenesisPriorityMap[type],
                toast: this.toast || 'transient',
                category: type,
                template: 'markdown',
                id: ALERT_ID,
                soundOptions: {
                    mode: this.mode,
                },
                indicator: {
                    text: title,
                    color: OpenfinGenesisColorMap[type],
                    fallback: OpenfinGenesisColorMap[type],
                },
                buttons: this.mapToastButtons(this.toastButtons, row),
                platform: (_a = this.notificationsPlatform) === null || _a === void 0 ? void 0 : _a.id,
            };
            try {
                yield create(notification);
            }
            catch (e) {
                console.error('Openfin notifications error', e);
            }
        });
    }
    mapToastButtons(toastButtons, row) {
        if (!toastButtons) {
            return null;
        }
        return toastButtons
            .filter((t) => {
            if (!t.task) {
                logger.warn('Interop Toast button config has no task specified');
                return false;
            }
            return !!t.condition({ details: row });
        })
            .map((t) => {
            return {
                title: t.placeholder,
                type: 'button',
                cta: t.cta,
                onClick: {
                    task: t.task,
                    customData: {
                        message: t.message,
                        details: row,
                    },
                },
            };
        });
    }
};
__decorate([
    attr
], OpenfinNotificationListener.prototype, "toast", void 0);
__decorate([
    attr
], OpenfinNotificationListener.prototype, "mode", void 0);
OpenfinNotificationListener = __decorate([
    customElement({
        name: 'openfin-notification-listener',
        template: html `
    <template ${ref('notificationListener')}>
      <slot></slot>
    </template>
  `,
    })
], OpenfinNotificationListener);
export { OpenfinNotificationListener };
